package pwc.taxtech.atms.controller;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import pwc.taxtech.atms.dto.OperationResultDto;
import pwc.taxtech.atms.dto.navtree.NavTreeDto;
import pwc.taxtech.atms.organization.dpo.OrganizationHKDto;
import pwc.taxtech.atms.organization.entity.OrganizationHK;
import pwc.taxtech.atms.service.impl.OrganizationHKServiceImpl;

import java.util.List;

@RestController
@RequestMapping("/api/v1/orgHK/")
public class OrganizationHKController {

    private static Logger logger = LoggerFactory.getLogger(OrganizationHKController.class);

    @Autowired
    OrganizationHKServiceImpl organizationHKService;

    @RequestMapping(value = "getOrgInfoList", method = RequestMethod.GET)
    public @ResponseBody
    List<OrganizationHK> getOrgInfoList() {
        logger.info("GET /api/v1/orgHK/getOrgInfoList");
        return organizationHKService.getOrgInfo();
    }

    @RequestMapping(value = "enableOrgs", method = RequestMethod.GET)
    public @ResponseBody
    OperationResultDto enableOrgs(@RequestParam("orgId") Long orgId) {
        logger.info("POST /api/v1/orgHK/enableOrgs");
        return organizationHKService.enableOrgs(orgId);
    }

    @RequestMapping(value = "disableOrgs", method = RequestMethod.POST)
    public @ResponseBody
    OperationResultDto disableOrgs(@RequestBody List<Long> orgIds) {
        logger.info("POST /api/v1/orgHK/disableOrgs");
        return organizationHKService.disableOrgs(orgIds);
    }

    @RequestMapping(value = "update", method = RequestMethod.PUT)
    public @ResponseBody
    OperationResultDto<Object> updateOrg(@RequestBody OrganizationHKDto orgDto) {
        logger.info("PUT /api/v1/orgHK/update");
        return organizationHKService.updateOrg(orgDto);
    }

    @RequestMapping(value = "getjson", method = RequestMethod.GET)
    public @ResponseBody
    List<NavTreeDto> getOrgListToJson(@RequestParam("useType") Integer useType) {
        logger.info("GET /api/v1/orgHK/getjson");
        return organizationHKService.getOrgListToJson(useType);
    }

    @RequestMapping(value = "displaySingle", method = RequestMethod.GET)
    public @ResponseBody
    OrganizationHKDto getSingleOrgByOrgId(@RequestParam("orgId") Long orgId) {
        logger.info("POST /api/v1/orgHK/displaySingle");
        return organizationHKService.getSingleOrgByOrgId(orgId);
    }

    @RequestMapping(value = "add", method = RequestMethod.POST)
    public @ResponseBody
    OperationResultDto<Object> addOrg(@RequestBody OrganizationHKDto orgDto) {
        logger.info("POST /api/v1/orgHK/add");
        return organizationHKService.addOrg(orgDto);
    }
}
